@@ -1,5 +1,6 @@
 from typing import List
 from functools import reduce
+import re
 from hestia_earth.schema import SiteSiteType
 
 from hestia_earth.geojson import get_geojson_area
@@ -108,6 +109,15 @@ def validate_region(site: dict):
     }
 
 
+def validate_country(site: dict):
+    country_id = site.get('country').get('@id')
+    return bool(re.search(r'GADM-[A-Z]{3}', country_id)) or {
+        'level': 'error',
+        'dataPath': '.country',
+        'message': 'must be a country'
+    }
+
+
 def need_validate_coordinates(site: dict):
     return 'latitude' in site and 'longitude' in site and site.get('siteType') in INLAND_TYPES
 
@@ -131,6 +141,7 @@ def validate_coordinates(site: dict):
 def validate_site(site: dict):
     return [
         validate_site_dates(site),
+        validate_country(site) if 'country' in site else True,
         validate_region(site) if 'region' in site else True,
         validate_coordinates(site) if need_validate_coordinates(site) else True,
         validate_area(site) if 'area' in site and 'boundary' in site else True
